==> estateplat-common-1.2.4-20191218.081439-225-sources.jar: cn/gtmap/estateplat/model/information/core/XxGhhg.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 建设工程规划核实合格证模型
 */
@Table(name = "xx_ghhg")
public class XxGhhg extends XxMxParent implements InsertVo, XxMxVo {
    @Id
    private String ywid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String jsdw;//建设单位（个人）
    @Column
    private String jsxmmc;//建设项目名称
    @Column
    private String jswz;//建设位置
    @Column
    private String jsgm;//建设规模
    @Column
    private String bz; //备注
    @Column
    private String xxgxqk;//信息共享情况

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getJsdw() {
        return jsdw;
    }

    public void setJsdw(String jsdw) {
        this.jsdw = jsdw;
    }

    public String getJsxmmc() {
        return jsxmmc;
    }

    public void setJsxmmc(String jsxmmc) {
        this.jsxmmc = jsxmmc;
    }

    public String getJswz() {
        return jswz;
    }

    public void setJswz(String jswz) {
        this.jswz = jswz;
    }

    public String getJsgm() {
        return jsgm;
    }

    public void setJsgm(String jsgm) {
        this.jsgm = jsgm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXxgxqk() {
        return xxgxqk;
    }

    public void setXxgxqk(String xxgxqk) {
        this.xxgxqk = xxgxqk;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }


    @Override
    public void setDwmc(String dwmc) {
        super.dwmc = "XXXX";
    }

    @Override
    public void setDwbm(String dwbm) {
        super.dwbm = "XXXX";
    }

    @Override
    public void setMxlx(String mxlx) {
        super.mxlx = "ghhg";
    }
}

==> estateplat-common-1.2.4-20210524.092848-775-sources.jar: cn/gtmap/estateplat/model/information/core/XxGhhg.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 建设工程规划核实合格证模型
 */
@Table(name = "xx_ghhg")
public class XxGhhg extends XxMxParent implements InsertVo, XxMxVo {
    @Id
    private String ywid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String jsdw;//建设单位（个人）
    @Column
    private String jsxmmc;//建设项目名称
    @Column
    private String jswz;//建设位置
    @Column
    private String jsgm;//建设规模
    @Column
    private String bz; //备注
    @Column
    private String xxgxqk;//信息共享情况
    @Column
    private String tjzt;//提交状态

    public String getTjzt() {
        return tjzt;
    }

    public void setTjzt(String tjzt) {
        this.tjzt = tjzt;
    }

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getJsdw() {
        return jsdw;
    }

    public void setJsdw(String jsdw) {
        this.jsdw = jsdw;
    }

    public String getJsxmmc() {
        return jsxmmc;
    }

    public void setJsxmmc(String jsxmmc) {
        this.jsxmmc = jsxmmc;
    }

    public String getJswz() {
        return jswz;
    }

    public void setJswz(String jswz) {
        this.jswz = jswz;
    }

    public String getJsgm() {
        return jsgm;
    }

    public void setJsgm(String jsgm) {
        this.jsgm = jsgm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXxgxqk() {
        return xxgxqk;
    }

    public void setXxgxqk(String xxgxqk) {
        this.xxgxqk = xxgxqk;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }


    @Override
    public void setDwmc(String dwmc) {
        super.dwmc = "XXXX";
    }

    @Override
    public void setDwbm(String dwbm) {
        super.dwbm = "XXXX";
    }

    @Override
    public void setMxlx(String mxlx) {
        super.mxlx = "ghhg";
    }
}
